@@ -1,6 +1,6 @@
 package Protocol::SPDY::Stream;
 {
-  $Protocol::SPDY::Stream::VERSION = '0.999_006';
+  $Protocol::SPDY::Stream::VERSION = '0.999_007';
 }
 use strict;
 use warnings;
@@ -12,7 +12,7 @@ Protocol::SPDY::Stream - single stream representation within a L<Protocol::SPDY>
 
 =head1 VERSION
 
-version 0.999_006
+version 0.999_007
 
 =head1 SYNOPSIS
 
@@ -233,8 +233,7 @@ sub new_from_syn {
 		# side, this means it's server-push stream.
 		$self->{associated_stream_id} = $parent_id;
 		die "not unidirectional?" unless $frame->uni;
-		die "no associated stream for $parent_id on " . $self->id unless $self->associated_stream;
-		$self->associated_stream->invoke_event(push => $self);
+		$self->associated_stream->invoke_event(push => $self) if $self->associated_stream;
 		$self->accepted->done;
 	}
 	$self;
@@ -729,6 +728,42 @@ sub accepted {
 
 __END__
 
+=head1 EVENTS
+
+The following events may be raised by this class - use
+L<Mixin::Event::Dispatch/subscribe_to_event> to watch for them:
+
+ $stream->subscribe_to_event(
+   push => sub {
+     my ($ev, $stream) = @_;
+	 print "Server push: received new stream $stream\n";
+   }
+ );
+
+=head2 push event
+
+Called when we have received a new stream from the other side
+with an associated stream. This currently means the server is
+pre-emptively sending data to us, see L</Server push support>.
+Will be passed the new L<Protocol::SPDY::Stream> instance.
+
+=head2 data event
+
+This will be called whenever we receive data from the other
+side. Will be passed the data payload as a scalar.
+
+=head2 transfer_window event
+
+The remote has sent us a WINDOW_UPDATE packet which means we
+have just updated our transfer window. Will be called with
+the new transfer window size and the delta in bytes.
+
+=head2 headers event
+
+New headers have been received on this stream. Will be called
+with the L<Protocol::SPDY::Frame::Control::HEADERS> containing
+the header information.
+
 =head1 COMPONENTS
 
 Further documentation can be found in the following modules:
